aind\_metadata\_mapper.u19 package
==================================

Submodules
----------

aind\_metadata\_mapper.u19.models module
----------------------------------------

.. automodule:: aind_metadata_mapper.u19.models
   :members:
   :undoc-members:
   :show-inheritance:

aind\_metadata\_mapper.u19.procedures module
--------------------------------------------

.. automodule:: aind_metadata_mapper.u19.procedures
   :members:
   :undoc-members:
   :show-inheritance:

aind\_metadata\_mapper.u19.utils module
---------------------------------------

.. automodule:: aind_metadata_mapper.u19.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: aind_metadata_mapper.u19
   :members:
   :undoc-members:
   :show-inheritance:
